@@ -14,7 +14,7 @@ Usage::
     client: BackupClient = boto3.client("backup")
     session_client: BackupClient = session.client("backup")
 """
-from mypy_boto3_backup.client import BackupClient as Client, BackupClient
+from mypy_boto3_backup.client import BackupClient, BackupClient as Client
 
 
 __all__ = ("BackupClient", "Client")
